@@ -4,12 +4,10 @@ use utf8;
 
 package SDK::SoundCloud::OAuth2Token;
 
-use Data::Dumper;
-
 use Moo::Role;
 use namespace::clean;
 
-use MooseX::Params::Validate;
+use Params::Validate qw(:all);
 
 requires 'client_id';
 
@@ -21,16 +19,22 @@ has 'path' => (
 );
 
 sub get_token {
-    my ($self, %params) = validated_hash(
-        \@_,
-        client_secret => { isa => 'Str' },
-        redirect_uri => { isa => 'Str' },
-        code => { isa => 'Str' },
+    my $self = shift @_;
+    my %params = validate(
+        @_, {
+        client_secret => { type => SCALAR  },
+        redirect_uri => { type => SCALAR },
+        code => { type => SCALAR },
         grant_type => {
-            isa => 'Str',
-            default => 'authorization_code' #refresh_token, password, client_credentials, oauth1_token
+            isa => SCALAR,
+            default => 'authorization_code', 
+            callbacks => {
+                'g type' => sub {
+                    return $_[0] if $_[0] =~ /^authorization_code|refresh_token|password|client_credentials|oauth1_token$/;
+                }
+            }
         }
-    );
+    });
 
     $params{client_id} = $self->client_id;
 
